cmoncrawl.processor.pipeline.streamer.StreamerFileHTML.stream
=============================================================

.. currentmodule:: cmoncrawl.processor.pipeline.streamer

.. automethod:: StreamerFileHTML.stream